package v1

import (
	"property-system-gateway/param/base"
	"property-system-gateway/pb/v1"
)

type ChargeConfAddBody struct {
	// 费用类型1 物业费 2 水费 3 电费 4 气费 5 车位管理费 6 月租停车费 99 其他
	ChargeType int32 `form:"charge_type" json:"charge_type"`
	// 费用名称
	ChargeName string `form:"charge_name" json:"charge_name"`
	// 缴费时间类型 1 周期性缴 2 一次性
	ChargeTimeType int32 `form:"charge_time_type" json:"charge_time_type"`
	// 账单生成周期 1 按月 2 按季度 3 半年 4 年
	BillPeriod int32 `form:"bill_period" json:"bill_period"`
	// 账单周期计算方式 1自然周期 2 费用生效时间
	BillPeriodType int32 `form:"bill_period_type" json:"bill_period_type"`
	// 1 按房屋面积 2 按使用面积 3 按车位面积 4 按使用量 5 固定费用 6 自定义
	ChargeBasis int32 `form:"charge_basis" json:"charge_basis"`
	// 滞纳金开启关闭
	LateFeeEnable bool `form:"late_fee_enable" json:"late_fee_enable"`
	// 固定费用
	FixAmount int64 `form:"fix_amount" json:"fix_amount"`
	// 固定费用别名
	FixAmountName string `form:"fix_amount_name" json:"fix_amount_name"`
	// 费用生效时间
	ChargeEffectiveTime int64 `form:"charge_effective_time" json:"charge_effective_time"`
	// 单价
	UnitPrice int64 `form:"unit_price" json:"unit_price"`
	// 账单生成后xx天开始算滞纳金
	LateFeeDay int64 `form:"late_fee_day" json:"late_fee_day"`
	// 滞纳金封顶天数
	LateFeeMaxDays int64 `form:"late_fee_max_days" json:"late_fee_max_days"`
	// 滞纳金比例 1代表万分之1
	LateFeePercent int64
}

type ChargeConfAddRequest struct {
	base.Header
	ChargeConfAddBody
}

type ChargeConfAddResponse struct {
	base.Result
	Data v1.ChargeConfAddReply `json:"data"`
}

type ChargeConfUpdateBody struct {
	// 费用类型1 物业费 2 水费 3 电费 4 气费 5 车位管理费 6 月租停车费 99 其他
	ChargeType int32 `form:"charge_type" json:"charge_type"`
	// 费用名称
	ChargeName string `form:"charge_name" json:"charge_name"`
	// 缴费时间类型 1 周期性缴 2 一次性
	ChargeTimeType int32 `form:"charge_time_type" json:"charge_time_type"`
	// 账单生成周期 1 按月 2 按季度 3 半年 4 年
	BillPeriod int32 `form:"bill_period" json:"bill_period"`
	// 账单周期计算方式 1自然周期 2 费用生效时间
	BillPeriodType int32 `form:"bill_period_type" json:"bill_period_type"`
	// 1 按房屋面积 2 按使用面积 3 按车位面积 4 按使用量 5 固定费用 6 自定义
	ChargeBasis int32 `form:"charge_basis" json:"charge_basis"`
	// 滞纳金开启关闭
	LateFeeEnable bool `form:"late_fee_enable" json:"late_fee_enable"`
	// 固定费用
	FixAmount int64 `form:"fix_amount" json:"fix_amount"`
	// 固定费用别名
	FixAmountName string `form:"fix_amount_name" json:"fix_amount_name"`
	// 费用生效时间
	ChargeEffectiveTime int64 `form:"charge_effective_time" json:"charge_effective_time"`
	// 单价
	UnitPrice int64 `form:"unit_price" json:"unit_price"`
	// 账单生成后xx天开始算滞纳金
	LateFeeDay int64 `form:"late_fee_day" json:"late_fee_day"`
	// 滞纳金封顶天数
	LateFeeMaxDays int64 `form:"late_fee_max_days" json:"late_fee_max_days"`
	// 滞纳金比例 1代表万分之1
	LateFeePercent int64

	Id int64 `form:"id"`
}

type ChargeConfUpdateRequest struct {
	base.Header
	ChargeConfUpdateBody
}

type ChargeConfUpdateResponse struct {
	base.Result
}

type ChargeConfDelQuery struct {
	Id int64 `form:"id"`
}

type ChargeConfDelRequest struct {
	base.Header
	ChargeConfDelQuery
}

type ChargeConfDelResponse struct {
	base.Result
}

type ChargeConfListQuery struct {
	Page       int64 `form:"page" json:"page"`
	PageSize   int64 `form:"page_size" json:"page_size"`
	ChargeType int32 `form:"charge_type" json:"charge_type"`
	ChargeName int32 `form:"charge_name" json:"charge_name"`
}

type ChargeConfListRequest struct {
	base.Header
	ChargeConfListQuery
}

type ChargeConfListResponse struct {
	base.Result
	Data v1.ChargeConfListReply `json:"data"`
}

type PowerRecordAddBody struct {
	// 费用类型
	ChargeType int32 `form:"charge_type" json:"charge_type"`
	// 上期抄表数
	LastAmount float64 `form:"last_amount" json:"last_amount"`
	// 本期抄表数
	CurrentAmount float64 `form:"current_amount" json:"current_amount"`
	// 开始时间戳
	Start int64 `form:"start" json:"start"`
	// 结束时间戳
	End int64 `form:"end" json:"end"`
	// 备注
	Comment string `form:"comment" json:"comment"`
	// 房屋id
	HouseId int64 `form:"house_id" json:"house_id"`
}

type PowerRecordAddRequest struct {
	base.Header
	PowerRecordAddBody
}

type PowerRecordAddResponse struct {
	base.Result
	Data v1.PowerRecordAddReply `json:"data"`
}

type PowerRecordDelQuery struct {
	Id int64 `form:"id"`
}

type PowerRecordDelRequest struct {
	base.Header
	PowerRecordDelQuery
}

type PowerRecordDelResponse struct {
	base.Result
}

type PowerRecordListQuery struct {
	HouseId    int64 `form:"house_id" json:"house_id"`
	ChargeType int32 `form:"charge_type" json:"charge_type"`
	Page       int64 `form:"page" json:"page"`
	PageSize   int64 `form:"page_size" json:"page_size"`
}

type PowerRecordListRequest struct {
	base.Header
	PowerRecordListQuery
}

type PowerRecordListResponse struct {
	base.Result
	Data v1.PowerRecordListReply `json:"data"`
}

type PowerRecordBatchAddQuery struct {
	ChargeType int32 `form:"charge_type" json:"charge_type"`
}

type PowerRecordBatchAddRequest struct {
	base.Header
	PowerRecordBatchAddQuery
}

type PowerRecordBatchAddResponse struct {
	base.Result
}

// 费用绑定对象
type ChargeBindBody struct {
	// 绑定对象的id
	ObjIds   []int64 `form:"obj_ids" json:"obj_ids"`
	ChargeId int64   `form:"charge_id" json:"charge_id"`
	// 开始时间
	Start int64 `form:"start" json:"start"`
	// 只有车辆费用有，结束时间
	End       int64 `form:"end" json:"end"`
	CustomFee int64 `form:"custom_fee" json:"custom_fee"`
}

type ChargeBindRequest struct {
	base.Header
	ChargeBindBody
}

type ChargeBindResponse struct {
	base.Result
}

// 费用解绑对象
type ChargeUnbindBody struct {
	ObjId    int64 `form:"obj_id" json:"obj_id"`
	ChargeId int64 `form:"charge_id" json:"charge_id"`
}

type ChargeUnbindRequest struct {
	base.Header
	ChargeUnbindBody
}

type ChargeUnbindResponse struct {
	base.Result
}

// 绑定了项目的房屋列表
type ChargeHouseBindedListQuery struct {
	ChargeId int64 `form:"charge_id" json:"charge_id"`
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
}

type ChargeHouseBindedListRequest struct {
	base.Header
	ChargeHouseBindedListQuery
}

type ChargeHouseBindedListResponse struct {
	base.Result
	Data v1.ChargeHouseBindedListReply `json:"data"`
}

// 可以绑定某项目的房屋列表
type ChargeHouseNotBindListQuery struct {
	ChargeId  int64  `form:"charge_id" json:"charge_id"`
	Page      int64  `form:"page" json:"page"`
	PageSize  int64  `form:"page_size" json:"page_size"`
	HouseName string `form:"house_name" json:"house_name"`
}

type ChargeHouseNotBindListRequest struct {
	base.Header
	ChargeHouseNotBindListQuery
}

type ChargeHouseNotBindListResponse struct {
	base.Result
	Data v1.ChargeHouseNotBindListReply `json:"data"`
}

// 绑定了某项目的车位列表
type ChargeSpaceBindedListQuery struct {
	ChargeId int64 `form:"charge_id" json:"charge_id"`
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
}

type ChargeSpaceBindedListRequest struct {
	base.Header
	ChargeSpaceBindedListQuery
}

type ChargeSpaceBindedListResponse struct {
	base.Result
	Data v1.ChargeSpaceBindedListReply `json:"data"`
}

// 可以绑定某项目的车位列表
type ChargeSpaceNotBindListQuery struct {
	ChargeId int64 `form:"charge_id" json:"charge_id"`
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
}

type ChargeSpaceNotBindListRequest struct {
	base.Header
	ChargeSpaceNotBindListQuery
}

type ChargeSpaceNotBindListResponse struct {
	base.Result
	Data v1.ChargeSpaceNotBindListReply `json:"data"`
}

// 绑定了某项目的车辆列表
type ChargeVehicleBindedListQuery struct {
	ChargeId int64 `form:"charge_id" json:"charge_id"`
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
}

type ChargeVehicleBindedListRequest struct {
	base.Header
	ChargeVehicleBindedListQuery
}

type ChargeVehicleBindedListResponse struct {
	base.Result
	Data v1.ChargeVehicleBindedListReply `json:"data"`
}

// 可以绑定某项目的车辆列表
type ChargeVehicleNotBindListQuery struct {
	ChargeId int64 `form:"charge_id" json:"charge_id"`
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
}

type ChargeVehicleNotBindListRequest struct {
	base.Header
	ChargeVehicleNotBindListQuery
}

type ChargeVehicleNotBindListResponse struct {
	base.Result
	Data v1.ChargeVehicleNotBindListReply `json:"data"`
}

// 房屋收费 房屋列表
type ChargeHouseGroupQuery struct {
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
}
type ChargeHouseGroupRequest struct {
	base.Header
	ChargeHouseGroupQuery
}

type ChargeHouseGroupResponse struct {
	base.Result
	Data v1.ChargeHouseGroupReply `json:"data"`
}

// 车位收费 车位列表
type ChargeSpaceGroupQuery struct {
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
}
type ChargeSpaceGroupRequest struct {
	base.Header
	ChargeSpaceGroupQuery
}

type ChargeSpaceGroupResponse struct {
	base.Result
	Data v1.ChargeSpaceGroupReply `json:"data"`
}

// 车辆收费 车辆列表
type ChargeVehicleGroupQuery struct {
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
}
type ChargeVehicleGroupRequest struct {
	base.Header
	ChargeVehicleGroupQuery
}

type ChargeVehicleGroupResponse struct {
	base.Result
	Data v1.ChargeVehicleGroupReply `json:"data"`
}

// 欠费线下缴费
type ChargeBillPayBody struct {
	//BillIds              []int64  `form:"bill_ids" json:"bill_ids"`
	// 绑定关系id列表
	BindIds []int64 `form:"bind_ids" json:"bind_ids"`
	// 1 现金 2 微信 3 支付宝 4 pos 5 转账
	PayType int32 `form:"pay_type" json:"pay_type"`
	// 应缴
	ShouldPayAmount int64 `form:"should_pay_amount" json:"should_pay_amount"`
	// 实缴
	PayAmount int64 `form:"pay_amount" json:"pay_amount"`
	// 备注
	Comment string `form:"comment" json:"comment"`
}

type ChargeBillPayRequest struct {
	base.Header
	ChargeBillPayBody
}

type ChargeBillPayResponse struct {
	base.Result
	Data v1.ChargeBillPayReply `json:"data"`
}

// 欠费缴费欠费列表
type ChargeUnpayListQuery struct {
	// 对象id
	ObjId int64 `form:"obj_id" json:"obj_id"`
	// 对象类型
	ObjType  int32 `form:"obj_type" json:"obj_type"`
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
}

type ChargeUnpayListRequest struct {
	base.Header
	ChargeUnpayListQuery
}

type ChargeUnpayListResponse struct {
	base.Result
	Data v1.ChargeUnpayListReply `json:"data"`
}

// 查看费用，费项列表
type ChargeListQuery struct {
	// 对象id
	ObjId int64 `form:"obj_id" json:"obj_id"`
	// 对象类型
	ObjType  int32 `form:"obj_type" json:"obj_type"`
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
}

type ChargeListRequest struct {
	base.Header
	ChargeListQuery
}

type ChargeListResponse struct {
	base.Result
	Data v1.ChargeListReply `json:"data"`
}

// 对象的某费项下的待缴账单列表
type ChargeBillListQuery struct {
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
	BindId   int64 `form:"bind_id" json:"bind_id"`
}

type ChargeBillListRequest struct {
	base.Header
	ChargeBillListQuery
}

type ChargeBillListResponse struct {
	base.Result
	Data v1.ChargeBillListReply `json:"data"`
}

// 应收账单中的对象列表
type ChargeBillObjListQuery struct {
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
}

type ChargeBillObjListRequest struct {
	base.Header
	ChargeBillObjListQuery
}
type ChargeBillObjListResponse struct {
	base.Result
	Data v1.ChargeBillObjListReply `json:"data"`
}

// 应收账单中某对象的账单明细
type ChargeObjBillListQuery struct {
	ObjId    int64 `form:"obj_id" json:"obj_id"`
	ObjType  int32 `form:"obj_type" json:"obj_type"`
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`

	// 对象名称
	ObjName string `form:"obj_name" json:"obj_name"`
	// 费用类型
	ChargeType int32 `form:"charge_type" json:"charge_type"`
	// 费用名称
	ChargeName string `form:"charge_name" json:"charge_name"`
}

type ChargeObjBillListRequest struct {
	base.Header
	ChargeObjBillListQuery
}

type ChargeObjBillListResponse struct {
	base.Result
	Data v1.ChargeObjBillListReply `json:"data"`
}

// 变更时间
type ChargeTimeSetBody struct {
	Start int64 `form:"start" json:"start"`
	// 仅车辆费用可以设结束时间
	End    int64 `form:"end" json:"end"`
	BindId int64 `form:"bind_id" json:"bind_id"`
}

type ChargeTimeSetRequest struct {
	base.Header
	ChargeTimeSetBody
}

type ChargeTimeSetResponse struct {
	base.Result
}

// 小票和收据信息
type ChargeOrderTicketQuery struct {
	OrderId string `form:"order_id" json:"order_id"`
}
type ChargeOrderTicketRequest struct {
	base.Header
	ChargeOrderTicketQuery
}
type ChargeOrderTicketResponse struct {
	base.Result
	Data v1.ChargeOrderTicketReply `json:"data"`
}

// 预缴物业费或车位费前获取对应的金额信息
type ChargePrePayInfoQuery struct {
	BindId int64 `form:"bind_id" json:"bind_id"`
	// 月数
	Months int64 `form:"months" json:"months"`
}

type ChargePrePayInfoRequest struct {
	base.Header
	ChargePrePayInfoQuery
}
type ChargePrePayInfoResponse struct {
	base.Result
	Data v1.ChargePrePayInfoReply `json:"data"`
}

// 线下预缴物业费或车位费
type ChargePrePayBody struct {
	BindId int64 `form:"bind_id" json:"bind_id"`
	Months int64 `form:"months" json:"months"`
	// 应缴金额
	ShouldPayAmount int64 `form:"should_pay_amount" json:"should_pay_amount"`
	// 实缴金额
	PayAmount int64 `form:"pay_amount" json:"pay_amount"`
	// 备注
	Comment string `form:"comment" json:"comment"`
	// 1 现金 2 微信 3 支付宝 4 pos 5 转账
	PayType int32 `form:"pay_type" json:"pay_type"`
}

type ChargePrePayRequest struct {
	base.Header
	ChargePrePayBody
}

type ChargePrePayResponse struct {
	base.Result
	Data v1.ChargePrePayReply `json:"data"`
}

// 已交账单列表
type ChargePayedBillListQuery struct {
	// 对象名称
	ObjName  string `form:"obj_name" json:"obj_name"`
	Page     int64  `form:"page" json:"page"`
	PageSize int64  `form:"page_size" json:"page_size"`
	// 费用类型
	ChargeType int32 `form:"charge_type" json:"charge_type"`
	// 费用名称
	ChargeName string `form:"charge_name" json:"charge_name"`

	ObjType int32 `form:"obj_type" json:"obj_type"`
}

type ChargePayedBillListRequest struct {
	base.Header
	ChargePayedBillListQuery
}

type ChargePayedBillListResponse struct {
	base.Result
	Data v1.ChargePayedBillListReply `json:"data"`
}

// 作废账单
type ChargeDelBillBody struct {
	BillId    int64  `form:"bill_id" json:"bill_id"`
	DelReason string `form:"del_reason" json:"del_reason"`
}

type ChargeDelBillRequest struct {
	base.Header
	ChargeDelBillBody
}

type ChargeDelBillResponse struct {
	base.Result
}

// 恢复账单
type ChargeRecoverBillBody struct {
	BillId int64 `form:"bill_id" json:"bill_id"`
}

type ChargeRecoverBillRequest struct {
	base.Header
	ChargeRecoverBillBody
}

type ChargeRecoverBillResponse struct {
	base.Result
}

// 作废账单列表
type ChargeDelBillListQuery struct {
	// 对象名称
	ObjName  string `form:"obj_name" json:"obj_name"`
	Page     int64  `form:"page" json:"page"`
	PageSize int64  `form:"page_size" json:"page_size"`
	// 费用类型
	ChargeType int32 `form:"charge_type" json:"charge_type"`
	// 费用名称
	ChargeName string `form:"charge_name" json:"charge_name"`
	ObjType    int32  `form:"obj_type" json:"obj_type"`
}

type ChargeDelBillListRequest struct {
	base.Header
	ChargeDelBillListQuery
}

type ChargeDelBillListResponse struct {
	base.Result
	Data v1.ChargeDelBillListReply `json:"data"`
}

// 缴费订单列表
type ChargeOrderListQuery struct {
	ObjName  string `form:"obj_name" json:"obj_name"`
	Page     int64  `form:"page" json:"page"`
	PageSize int64  `form:"page_size" json:"page_size"`
	PayType  int32  `form:"pay_type" json:"pay_type"`
	OrderId  string `form:"order_id" json:"order_id"`
	// 1 待支付 2 已支付
	PayStatus int32 `form:"pay_status" json:"pay_status"`
}

type ChargeOrderListRequest struct {
	base.Header
	ChargeOrderListQuery
}

type ChargeOrderListResponse struct {
	base.Result
	Data v1.ChargeOrderListReply `json:"data"`
}

// 缴费订单详情
type ChargeOrderInfoQuery struct {
	OrderId string `form:"order_id" json:"order_id"`
}
type ChargeOrderInfoRequest struct {
	base.Header
	ChargeOrderInfoQuery
}

type ChargeOrderInfoResponse struct {
	base.Result
	Data v1.ChargeOrderInfoReply `json:"data"`
}

// 确认已支付
type ChargeOrderPayBody struct {
	OrderId string `form:"order_id" json:"order_id"`
}
type ChargeOrderPayRequest struct {
	base.Header
	ChargeOrderPayBody
}
type ChargeOrderPayResponse struct {
	base.Result
}

type PropertyPackageAddBody struct {
	// 1 按月 2 按文本
	PackageType int32 `form:"package_type" json:"package_type"`
	// 赠送月数
	GiveMonths int64 `form:"give_months" json:"give_months"`
	// 增送文本
	GiveContent string `form:"give_content" json:"give_content"`
	// 购买月数
	PayMonths int64 `form:"pay_months" json:"pay_months"`
	Enable    bool  `form:"enable" json:"enable"`
}

type PropertyPackageAddRequest struct {
	base.Header
	PropertyPackageAddBody
}

type PropertyPackageAddResponse struct {
	base.Result
	Data v1.PropertyPackageAddReply `json:"data"`
}

type PropertyPackageUpdateBody struct {
	// 1 按月 2 按文本
	PackageType int32 `form:"package_type" json:"package_type"`
	// 赠送月数
	GiveMonths int64 `form:"give_months" json:"give_months"`
	// 增送文本
	GiveContent string `form:"give_content" json:"give_content"`
	// 购买月数
	PayMonths int64 `form:"pay_months" json:"pay_months"`
	Enable    bool  `form:"enable" json:"enable"`
	Id        int64 `form:"id"`
}

type PropertyPackageUpdateRequest struct {
	base.Header
	PropertyPackageUpdateBody
}

type PropertyPackageUpdateResponse struct {
	base.Result
}

type PropertyPackageDelQuery struct {
	Id int64 `form:"id"`
}

type PropertyPackageDelRequest struct {
	base.Header
	PropertyPackageDelQuery
}

type PropertyPackageDelResponse struct {
	base.Result
}

type PropertyPackageListQuery struct {
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
}

type PropertyPackageListRequest struct {
	base.Header
	PropertyPackageListQuery
}

type PropertyPackageListResponse struct {
	base.Result
	Data v1.PropertyPackageListReply `json:"data"`
}

type ChargeGenerateBillBody struct {
	BindId int64 `form:"bind_id" json:"bind_id"`
	End    int64 `form:"end" json:"end"`
}

type ChargeGenerateBillRequest struct {
	base.Header
	ChargeGenerateBillBody
}

type ChargeGenerateBillResponse struct {
	base.Result
}

type ChargeUrgeSetBody struct {
	UrgeDay int64 `form:"urge_day" json:"urge_day"`
	// 1 仅业主 2 业主和家人 3 业主家人租客
	UrgeTarget int32 `form:"urge_target" json:"urge_target"`
	//1 仅短信 2 仅微信 3 短信和微信
	UrgeMsgType int32 `form:"urge_msg_type" json:"urge_msg_type"`
	// 催缴信息返回的id为0时填0
	Id int64 `form:"id" json:"id"`
}

type ChargeUrgeSetRequest struct {
	base.Header
	ChargeUrgeSetBody
}

type ChargeUrgeSetResponse struct {
	base.Result
}

type ChargeUrgeInfoRequest struct {
	base.Header
}

type ChargeUrgeInfoResponse struct {
	base.Result
	Data v1.ChargeUrgeInfoReply `json:"data"`
}

type TemplateRequest struct {
	base.Header
}

type TemplateData struct {
	Url string `json:"url"`
}

type TemplateResponse struct {
	base.Result
	Data TemplateData `json:"data"`
}

type ChargeUrgeBody struct {
	ObjId   int64 `form:"obj_id" json:"obj_id"`
	ObjType int32 `form:"obj_type" json:"obj_type"`
}

type ChargeUrgeRequest struct {
	base.Header
	ChargeUrgeBody
}

type ChargeUrgeResponse struct {
	base.Result
}

type BatchUrgeQuery struct {
	ObjType int32 `form:"obj_type" json:"obj_type"`
}

type BatchUrgeRequest struct {
	base.Header
	BatchUrgeQuery
}

type BatchUrgeFeeItem struct {
	// 费用名称
	ChargeName string `json:"charge_name"`
	// 费用类型 1 物业费 2 水费 3 电费 4 气费 5 车位管理费 6 月租停车费 99 其他
	ChargeType int32 `json:"charge_type"`
	// 欠费金额
	Fee int64 `json:"fee"`
}
type BatchUrgeItem struct {
	// 房号/车位号
	ObjName string `json:"obj_name"`
	// 费用
	List []BatchUrgeFeeItem `json:"list"`
}

type BatchUrgeData struct {
	List []BatchUrgeItem `json:"list"`
}

type BatchUrgeResponse struct {
	base.Result
	Data BatchUrgeData `json:"data"`
}
