package v1

import (
	"property-system-gateway/param/base"
	"property-system-gateway/pb/v1"
)

type BuildingAddManagerBody struct {
	ManagerUid int64 `form:"manager_uid" json:"manager_uid"`
	BuildingId int64 `form:"building_id" json:"building_id"`
}

type BuildingAddManagerRequest struct {
	base.Header
	BuildingAddManagerBody
}

type BuildingAddManagerResponse struct {
	base.Result
	Data v1.BuildingAddManagerReply `json:"data"`
}

type BuildingDelManagerQuery struct {
	Id int64 `form:"id" json:"id"`
}

type BuildingDelManagerRequest struct {
	base.Header
	BuildingDelManagerQuery
}

type BuildingDelManagerResponse struct {
	base.Result
}
type BuildingManagerListQuery struct {
	BuildingId int64 `form:"building_id" json:"building_id"`
}
type BuildingManagerListRequest struct {
	base.Header
	BuildingManagerListQuery
}

type BuildingManagerListResponse struct {
	base.Result
	Data v1.BuildingManagerListReply `json:"data"`
}

type BuildingAddBody struct {
	// 楼栋编号
	BuildingNumber string `form:"building_number" json:"building_number"`
	// 楼栋名
	BuildingName string `form:"building_name" json:"building_name"`
	// 楼栋建筑面积
	BuildingArea float64 `form:"building_area" json:"building_area"`
	// 楼栋使用面积
	BuildingUsedArea float64 `form:"building_used_area" json:"building_used_area"`
	// 备注
	Comment string `form:"=comment" json:"comment"`
}
type BuildingAddRequest struct {
	base.Header
	BuildingAddBody
}

type BuildingAddResponse struct {
	base.Result
	Data v1.BuildingAddReply `json:"data"`
}

type BuildingUpdateBody struct {
	Id int64 `form:"id"`
	// 楼栋编号
	BuildingNumber string `form:"building_number" json:"building_number"`
	// 楼栋名
	BuildingName string `form:"building_name" json:"building_name"`
	// 楼栋建筑面积
	BuildingArea float64 `form:"building_area" json:"building_area"`
	// 楼栋使用面积
	BuildingUsedArea float64 `form:"building_used_area" json:"building_used_area"`
	// 备注
	Comment string `form:"=comment" json:"comment"`
}

type BuildingUpdateRequest struct {
	base.Header
	BuildingUpdateBody
}

type BuildingUpdateResponse struct {
	base.Result
}

type BuildingDelQuery struct {
	Id int64 `form:"id"`
}

type BuildingDelRequest struct {
	base.Header
	BuildingDelQuery
}

type BuildingDelResponse struct {
	base.Result
}

type BuildingListQuery struct {
	Page           int64  `form:"page"`
	PageSize       int64  `form:"page_size"`
	BuildingNumber string `form:"building_number" json:"building_number"`
}

type BuildingListRequest struct {
	base.Header
	BuildingListQuery
}

type BuildingListResponse struct {
	base.Result
	Data v1.BuildingListReply `json:"data"`
}

type UnitAddBody struct {
	BuildingId int64 `form:"building_id" json:"building_id"`
	// 单元编号
	UnitNumber int64 `form:"unit_number" json:"unit_number"`
	// 单元名
	UnitName string `form:"unit_name" json:"unit_name"`
	// 楼层数
	UnitLayers int64 `form:"unit_layers" json:"unit_layers"`
	// 是否有电梯
	HasLift bool `form:"has_lift" json:"has_lift"`
}
type UnitAddRequest struct {
	base.Header
	UnitAddBody
}

type UnitAddResponse struct {
	base.Result
	Data v1.UnitAddReply `json:"data"`
}

type UnitUpdateBody struct {
	Id         int64 `form:"id"`
	BuildingId int64 `form:"building_id" json:"building_id"`
	// 单元编号
	UnitNumber int64 `form:"unit_number" json:"unit_number"`
	// 单元名
	UnitName string `form:"unit_name" json:"unit_name"`
	// 楼层数
	UnitLayers int64 `form:"unit_layers" json:"unit_layers"`
	// 是否有电梯
	HasLift bool `form:"has_lift" json:"has_lift"`
}

type UnitUpdateRequest struct {
	base.Header
	UnitUpdateBody
}

type UnitUpdateResponse struct {
	base.Result
}

type UnitDelQuery struct {
	Id int64 `form:"id"`
}

type UnitDelRequest struct {
	base.Header
	UnitDelQuery
}

type UnitDelResponse struct {
	base.Result
}

type UnitListQuery struct {
	Page       int64 `form:"page"`
	PageSize   int64 `form:"page_size"`
	UnitNumber int64 `form:"unit_number" json:"unit_number"`
	BuildingId int64 `form:"building_id" json:"building_id"`
}

type UnitListRequest struct {
	base.Header
	UnitListQuery
}

type UnitListResponse struct {
	base.Result
	Data v1.UnitListReply `json:"data"`
}

type HouseAddBody struct {
	// 单元id
	UnitId int64 `form:"unit_id" json:"unit_id"`
	// 门牌号
	HouseNumber string `form:"house_number" json:"house_number"`
	// 楼层
	Layer int64 `form:"layer" json:"layer"`
	// 几室
	RoomCount int64 `form:"room_count" json:"room_count"`
	// 几厅
	HallCount int64 `form:"hall_count" json:"hall_count"`
	// 房屋类型 1 住宅 2 公寓 3 商业 4 洋房 5 别墅
	HouseType int64 `form:"house_type" json:"house_type"`
	// 房屋建筑面积
	HouseArea float64 `form:"house_area" json:"house_area"`
	// 房屋使用面积
	HouseUsedArea float64 `form:"house_used_area" json:"house_used_area"`
	BuildingId    int64   `form:"building_id" json:"building_id"`
}
type HouseAddRequest struct {
	base.Header
	HouseAddBody
}

type HouseAddResponse struct {
	base.Result
	Data v1.HouseAddReply `json:"data"`
}

type HouseUpdateBody struct {
	Id int64 `form:"id"`
	// 单元id
	UnitId int64 `form:"unit_id" json:"unit_id"`
	// 门牌号
	HouseNumber string `form:"house_number" json:"house_number"`
	// 楼层
	Layer int64 `form:"layer" json:"layer"`
	// 几室
	RoomCount int64 `form:"room_count" json:"room_count"`
	// 几厅
	HallCount int64 `form:"hall_count" json:"hall_count"`
	// 房屋类型 1 住宅 2 公寓 3 商业 4 洋房 5 别墅
	HouseType int64 `form:"house_type" json:"house_type"`
	// 房屋建筑面积
	HouseArea float64 `form:"house_area" json:"house_area"`
	// 房屋使用面积
	HouseUsedArea float64 `form:"house_used_area" json:"house_used_area"`
}

type HouseUpdateRequest struct {
	base.Header
	HouseUpdateBody
}

type HouseUpdateResponse struct {
	base.Result
}

type HouseDelQuery struct {
	Id int64 `form:"id"`
}

type HouseDelRequest struct {
	base.Header
	HouseDelQuery
}

type HouseDelResponse struct {
	base.Result
}

type HouseListQuery struct {
	Page         int64  `form:"page"`
	PageSize     int64  `form:"page_size"`
	HouseNumber  string `form:"house_number" json:"house_number"`
	HouseName    string `form:"house_name" json:"house_name"`
	BuildingId   int64  `form:"building_id" json:"building_id"`
	UnitId       int64  `form:"unit_id" json:"unit_id"`
	HouseType    int32  `form:"house_type" json:"house_type"`
	HouseholdUid int64  `form:"household_uid" json:"household_uid"`
	HouseRent    bool   `form:"house_rent" json:"house_rent"`
}

type HouseListRequest struct {
	base.Header
	HouseListQuery
}

type HouseListResponse struct {
	base.Result
	Data v1.HouseListReply `json:"data"`
}

type BatchHouseAddBody struct {
	Buildings []v1.BatchBuildingItem `form:"buildings"`
	Units     []v1.BatchUnitItem     `form:"units"`
	Houses    []v1.BatchHouseItem    `form:"houses"`
}

type BatchHouseAddRequest struct {
	base.Header
	BatchHouseAddBody
}

type BatchHouseAddResponse struct {
	base.Result
}

type GardenInfoRequest struct {
	base.Header
}

type GardenInfoResponse struct {
	base.Result
	Data v1.GardenItem `json:"data"`
}

type GardenUpdateBody struct {
	// 省
	//Province     string `form:"province" json:"province"`
	//ProvinceCode string `form:"province_code" json:"province_code"`
	// 市
	//City     string `form:"city" json:"city"`
	//CityCode string `form:"city_code" json:"city_code"`
	// 区
	//Area     string `form:"area" json:"area"`
	//AreaCode string `form:"area_code" json:"area_code"`
	// 街道
	//Street     string `form:"street" json:"street"`
	//StreetCode string `form:"street_code" json:"street_code"`
	// 社区
	//Committee     string `form:"committee" json:"committee"`
	//CommitteeCode string `form:"committee_code" json:"committee_code"`
	// 小区名字
	//GardenName string `form:"garden_name" json:"garden_name"`
	// 小区地址
	GardenAddr string `form:"garden_addr" json:"garden_addr"`
	// 物业联系人
	PropertyPerson string `form:"property_person" json:"property_person"`
	// 物业联系人手机号
	PropertyPhone string `form:"property_phone" json:"property_phone"`
	// 小区形象图片
	GardenPic string `form:"garden_pic" json:"garden_pic"`
	// 小区描述
	GardenDesc string `form:"garden_desc" json:"garden_desc"`
	// 经度
	Lnt float64 `form:"lnt" json:"lnt"`
	// 纬度
	Lat float64 `form:"lat" json:"lat"`

	// 1塔楼 2 板楼 3 塔板结合 4 其他
	BuildingType int32 `form:"building_type" json:"building_type"`
	// 建成年份开始时间戳
	BuildingStart int64 `form:"building_start" json:"building_start"`
	// 建成年份结束时间戳
	BuildingEnd int64 `form:"building_end" json:"building_end"`
	// 绿化率
	GreenPercent float64 `form:"green_percent" json:"green_percent"`
	// 容积率
	AreaPercent float64 `form:"area_percent" json:"area_percent"`
	// 车位配比
	SpaceInfo string `form:"space_info" json:"space_info"`
	// 占地面积
	CoveredArea float64 `form:"covered_area" json:"covered_area"`
	// 建筑面积
	BuildingArea float64 `form:"building_area" json:"building_area"`
	// 小区图片
	GardenPics []string `form:"garden_pics" json:"garden_pics"`
	// 开发企业
	BuildingCompany string `form:"building_company" json:"building_company"`
	// 总户数
	HouseTotal int64 `form:"house_total" json:"house_total"`
	// 固定车位数
	SpaceTotal int64 `form:"space_total" json:"space_total"`
	// 物业费开始，单位分
	PropertyFeeStart int64 `form:"property_fee_start" json:"property_fee_start"`
	// 物业费结束， 单位分
	PropertyFeeEnd int64 `form:"property_fee_end" json:"property_fee_end"`
	// 水费类型多选 1 民用 2 商用
	WaterType []int32 `form:"water_type" json:"water_type"`
	// 电费类型多选 1 民用 2 商用
	ElectricType []int32 `form:"electric_type" json:"electric_type"`
	// 燃气费开始，单位分
	GasFeeStart int64 `form:"gas_fee_start" json:"gas_fee_start"`
	// 燃气费开始，单位分
	GasFeeEnd int64 `form:"gas_fee_end" json:"gas_fee_end"`
	AvgPrice  int64 `form:"avg_price" json:"avg_price"`
}

type GardenUpdateRequest struct {
	base.Header
	GardenUpdateBody
}

type GardenUpdateResponse struct {
	base.Result
}

type GardenKeyInfoChangeBody struct {
	// 省
	Province     string `form:"province" json:"province"`
	ProvinceCode string `form:"province_code" json:"province_code"`
	// 市
	City     string `form:"city" json:"city"`
	CityCode string `form:"city_code" json:"city_code"`
	// 区
	Area     string `form:"area" json:"area"`
	AreaCode string `form:"area_code" json:"area_code"`
	// 街道
	Street     string `form:"street" json:"street"`
	StreetCode string `form:"street_code" json:"street_code"`
	// 社区
	Committee     string `form:"committee" json:"committee"`
	CommitteeCode string `form:"committee_code" json:"committee_code"`
	// 小区名字
	GardenName string `form:"garden_name" json:"garden_name"`
}
type GardenKeyInfoChangeRequest struct {
	base.Header
	GardenKeyInfoChangeBody
}

type GardenKeyInfoChangeResponse struct {
	base.Result
}

type GardenKeyInfoChangeListQuery struct {
	Page     int64 `form:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
	Status   int32 `form:"status" json:"status"`
}
type GardenKeyInfoChangeListRequest struct {
	base.Header
	GardenKeyInfoChangeListQuery
}

type GardenKeyInfoChangeListResponse struct {
	base.Result
	Data v1.GardenKeyInfoChangeListReply `json:"data"`
}
