package v1

import (
	"property-system-gateway/param/base"
	"property-system-gateway/pb/v1"
)

type GateUnitListQuery struct {
	DeviceId int64 `form:"device_id" json:"device_id"`
}
type GateUnitListRequest struct {
	base.Header
	GateUnitListQuery
}

type GateUnitBuildingUnitItem struct {
	UnitId     int64  `json:"unit_id"`
	UnitNumber int64  `json:"unit_number"`
	UnitName   string `json:"unit_name"`
	Selected   bool   `json:"selected"`
}

type GateUnitBuildingItem struct {
	BuildingNumber string                     `json:"building_number"`
	BuildingName   string                     `json:"building_name"`
	Units          []GateUnitBuildingUnitItem `json:"units"`
}

type GateUnitData struct {
	List []GateUnitBuildingItem `json:"list"`
}

type GateUnitListResponse struct {
	base.Result
	Data GateUnitData `json:"data"`
}

type GateUnitAddBody struct {
	DeviceId int64   `form:"device_id" json:"device_id"`
	UnitIds  []int64 `form:"unit_ids" json:"unit_id"`
}

type GateUnitAddRequest struct {
	base.Header
	GateUnitAddBody
}

type GateUnitAddResponse struct {
	base.Result
}

type GateCardSyncBody struct {
	// 卡的记录id
	Id int64 `form:"id" json:"id"`
}

type GateCardSyncRequest struct {
	base.Header
	GateCardSyncBody
}

type GateCardSyncResponse struct {
	base.Result
}

type GateCardAddBody struct {
	CardNumber string  `form:"card_number" json:"card_number"`
	Name       string  `form:"name" json:"name"`
	DeviceIds  []int64 `form:"device_ids" json:"device_ids"`
}

type GateCardAddRequest struct {
	base.Header
	GateCardAddBody
}

type GateCardAddResponse struct {
	base.Result
}

type GateCardListQuery struct {
	DownStatus int32  `form:"down_status" json:"down_status"`
	Name       string `form:"name" json:"name"`
	Page       int64  `form:"page" json:"page"`
	PageSize   int64  `form:"page_size" json:"page_size"`
}

type GateCardListRequest struct {
	base.Header
	GateCardListQuery
}

type GateCardListResponse struct {
	base.Result
	Data v1.GateCardListReply `json:"data"`
}

type GateCardCanBindDevicesQuery struct {
	CardNumber string `form:"card_number" json:"card_number"`
}
type GateCardCanBindDevicesRequest struct {
	base.Header
	GateCardCanBindDevicesQuery
}

type GateCardCanBindDevicesResponse struct {
	base.Result
	Data v1.GateCardCanBindDevicesReply `json:"data"`
}

type GateUserPicApproveBody struct {
	// 人脸记录id
	Id       int64  `form:"id" json:"id"`
	Status   bool   `form:"status" json:"status"`
	Feedback string `form:"feedback" json:"feedback"`
}

type GateUserPicApproveRequest struct {
	base.Header
	GateUserPicApproveBody
}

type GateUserPicApproveResponse struct {
	base.Result
}

type GateUserPicSyncBody struct {
	// 人脸记录id
	Id int64 `form:"id" json:"id"`
}

type GateUserPicSyncRequest struct {
	base.Header
	GateUserPicSyncBody
}

type GateUserPicSyncResponse struct {
	base.Result
}

type GateUserPicListQuery struct {
	DownStatus int32  `form:"down_status" json:"down_status"`
	Name       string `form:"name" json:"name"`
	Page       int64  `form:"page" json:"page"`
	PageSize   int64  `form:"page_size" json:"page_size"`
}

type GateUserPicListRequest struct {
	base.Header
	GateUserPicListQuery
}

type GateUserPicListResponse struct {
	base.Result
	Data v1.GateUserPicListReply `json:"data"`
}

type GateListQuery struct {
	Page       int64  `form:"page" json:"page"`
	PageSize   int64  `form:"page_size" json:"page_size"`
	Sn         string `form:"sn"`
	Manufactor string `form:"manufactor"`
	DeviceName string `form:"device_name"`
}
type GateListRequest struct {
	base.Header
	GateListQuery
}

type GateListResponse struct {
	base.Result
	Data v1.GateListReply `json:"data"`
}

type GateEnableBody struct {
	DeviceId int64 `form:"device_id" json:"device_id"`
	// true 启用 false 停用
	Enable bool `form:"enable" json:"enable"`
}

type GateEnableRequest struct {
	base.Header
	GateEnableBody
}

type GateEnableResponse struct {
	base.Result
}

type GateSetBody struct {
	DeviceId int64 `form:"device_id" json:"device_id"`
	// 1 进场 2 出场 3 进出场
	Direction int32 `form:"direction" json:"direction"`
	// 位置
	Location string `form:"location" json:"location"`
	GateName string `form:"gate_name" json:"gate_name"`
	Ip       string `form:"ip" json:"ip"`
	Mac      string `form:"mac" json:"mac"`
	User     string `form:"user" json:"user"`
	Password string `form:"password" json:"password"`
}
type GateSetRequest struct {
	base.Header
	GateSetBody
}
type GateSetResponse struct {
	base.Result
}

type GateOpenBody struct {
	DeviceId int64 `form:"device_id" json:"device_id"`
}
type GateOpenRequest struct {
	base.Header
	GateOpenBody
}
type GateOpenResponse struct {
	base.Result
}

type GateRestartBody struct {
	DeviceId int64 `form:"device_id" json:"device_id"`
}
type GateRestartRequest struct {
	base.Header
	GateRestartBody
}
type GateRestartResponse struct {
	base.Result
}

type GateCommandListQuery struct {
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
	DeviceId int64 `form:"device_id" json:"device_id"`
}

type GateCommandListRequest struct {
	base.Header
	GateCommandListQuery
}
type GateCommandListResponse struct {
	base.Result
	Data v1.GateCommandListReply `json:"data"`
}

type GateRecordListQuery struct {
	Page      int64  `form:"page" json:"page"`
	PageSize  int64  `form:"page_size" json:"page_size"`
	DeviceId  string `form:"device_id" json:"device_id"`
	Start     int64  `form:"start" json:"start"`
	End       int64  `form:"end" json:"end"`
	IsVisitor int32  `form:"is_visitor" json:"is_visitor"`
}

type GateRecordListRequest struct {
	base.Header
	GateRecordListQuery
}

type GateRecordListResponse struct {
	base.Result
	Data v1.GateRecordListReply `json:"data"`
}

type GateVisitorListQuery struct {
	Page     int64  `form:"page" json:"page"`
	PageSize int64  `form:"page_size" json:"page_size"`
	GateId   int64  `form:"gate_id" json:"gate_id"`
	User     string `form:"user"`
	Visitor  string `form:"visitor"`
	Start    int64  `form:"start"`
	End      int64  `form:"end"`
}

type GateVisitorListRequest struct {
	base.Header
	GateVisitorListQuery
}

type GateVisitorListResponse struct {
	base.Result
	Data v1.GateVisitorListReply `json:"data"`
}

type GateCardDelQuery struct {
	Id int64 `form:"id" json:"id"`
}

type GateCardDelRequest struct {
	base.Header
	GateCardDelQuery
}

type GateCardDelResponse struct {
	base.Result
}

type GateUserPicDelQuery struct {
	Id int64 `form:"id" json:"id"`
}

type GateUserPicDelRequest struct {
	base.Header
	GateUserPicDelQuery
}

type GateUserPicDelResponse struct {
	base.Result
}
