package v1

import (
	"property-system-gateway/param/base"
	pb_v1 "property-system-gateway/pb/v1"
)

type HouseRentApplyBody struct {
	// 房屋id
	HouseId int64 `form:"house_id" json:"house_id"`
	// 朝向
	Direction int32 `form:"direction" json:"direction"`
	// 几卫
	WcCount int64 `form:"wc_count" json:"wc_count"`
	// 1 精装 2 简装 3 清水
	Decorating int32 `form:"decorating" json:"decorating"`
	// 联系人
	Contacter string `form:"contacter" json:"contacter"`
	// 联系人电话
	ContactPhone string `form:"contact_phone" json:"contact_phone"`
	// 1 月付 2 季付 3 半年付 4 年付
	PayTimeType int32 `form:"pay_time_type" json:"pay_time_type"`
	// 1 整租 2 合租 3 转租
	RentType int32 `form:"rent_type" json:"rent_type"`
	// 1 全部 2 主卧 3 次卧
	RoomType int32 `form:"room_type" json:"room_type"`
	// 房间面积
	RoomArea float64 `form:"room_area" json:"room_area"`
	// 月租
	RentPrice int64 `form:"rent_price" json:"rent_price"`
	// 押金
	Desposit int64 `form:"desposit" json:"desposit"`
	// 可入住时间
	InTime int64 `form:"in_time" json:"in_time"`
	// 服务费
	ServicePrice int64 `form:"service_price" json:"service_price"`
	// 中介费
	IntermediaryPrice int64 `form:"intermediary_price" json:"intermediary_price"`
	// 基础设施 从低到高分别表示床 天然气 暖气 宽带 冰箱 衣柜 沙发 空调 电视机 热水器 洗衣机
	BaseConf int64 `form:"base_conf" json:"base_conf"`
	// 特色配置 从低到高分别表示 智能门锁 wifi 近地铁 停车位 独卫 私人阳台 首次出租
	SpecialConf int64 `form:"special_conf" json:"special_conf"`

	// 简介
	Desc string `form:"desc" json:"desc"`
	// 房屋图片
	HousePic []string `form:"house_pic" json:"house_pic"`
	// 房屋证件图片
	CertPic []string `form:"cert_pic" json:"cert_pic"`
	// 业主uid
	//HouseholdUid int64 `form:"household_uid" json:"household_uid"`

}

type HouseRentApplyRequest struct {
	base.Header
	HouseRentApplyBody
}

type HouseRentApplyResponse struct {
	base.Result
	Data pb_v1.HouseRentApplyReply `json:"data"`
}

type HouseRentUpdateBody struct {
	// 房屋id
	HouseId int64 `form:"house_id" json:"house_id"`
	// 朝向
	Direction int32 `form:"direction" json:"direction"`
	WcCount   int64 `form:"wc_count" json:"wc_count"`
	// 1 精装 2 简装 3 清水
	Decorating int32 `form:"decorating" json:"decorating"`
	// 联系人
	Contacter string `form:"contacter" json:"contacter"`
	// 联系人电话
	ContactPhone string `form:"contact_phone" json:"contact_phone"`
	// 1 月付 2 季付 3 半年付 4 年付
	PayTimeType int32 `form:"pay_time_type" json:"pay_time_type"`
	// 1 整租 2 合租 3 转租
	RentType int32 `form:"rent_type" json:"rent_type"`
	// 1 全部 2 主卧 3 次卧
	RoomType int32 `form:"room_type" json:"room_type"`
	// 房间面积
	RoomArea float64 `form:"room_area" json:"room_area"`
	// 月租
	RentPrice int64 `form:"rent_price" json:"rent_price"`
	// 押金
	Desposit int64 `form:"desposit" json:"desposit"`
	// 可入住时间
	InTime int64 `form:"in_time" json:"in_time"`
	// 服务费
	ServicePrice int64 `form:"service_price" json:"service_price"`
	// 中介费
	IntermediaryPrice int64 `form:"intermediary_price" json:"intermediary_price"`
	// 基础设施 从低到高分别表示床 天然气 暖气 宽带 冰箱 衣柜 沙发 空调 电视机 热水器 洗衣机
	BaseConf int64 `form:"base_conf" json:"base_conf"`
	// 特色配置 从低到高分别表示 智能门锁 wifi 近地铁 停车位 独卫 私人阳台 首次出租
	SpecialConf int64 `form:"special_conf" json:"special_conf"`
	// 简介
	Desc string `form:"desc" json:"desc"`
	// 房屋图片
	HousePic []string `form:"house_pic" json:"house_pic"`
	// 房屋证件图片
	CertPic []string `form:"cert_pic" json:"cert_pic"`
	// 业主uid
	//HouseholdUid int64 `form:"household_uid" json:"household_uid"`

	Id int64 `form:"id" json:"id"`
}

type HouseRentUpdateRequest struct {
	base.Header
	HouseRentUpdateBody
}

type HouseRentUpdateResponse struct {
	base.Result
}

type HouseRentApproveBody struct {
	Id       int64  `form:"id" json:"id"`
	Status   bool   `form:"status" json:"status"`
	Feedback string `form:"feedback" json:"feedback"`
}

type HouseRentApproveRequest struct {
	base.Header
	HouseRentApproveBody
}

type HouseRentApproveResponse struct {
	base.Result
}

type HouseRentDownBody struct {
	Id int64 `form:"id" json:"id"`
}

type HouseRentDownRequest struct {
	base.Header
	HouseRentDownBody
}

type HouseRentDownResponse struct {
	base.Result
}

type HouseRentListQuery struct {
	ProvinceCode     string `form:"province_code" json:"province_code"`
	CityCode         string `form:"city_code" json:"city_code"`
	AreaCode         string `form:"area_code" json:"area_code"`
	StreetCode       string `form:"street_code" json:"street_code"`
	RoomCount        int64  `form:"room_count" json:"room_count"`
	HallCount        int64  `form:"hall_count" json:"hall_count"`
	WcCount          int64  `form:"wc_count" json:"wc_count"`
	HouseholdUid     int64  `form:"household_uid" json:"household_uid"`
	RentPriceGreater int64  `form:"rent_price_greater" json:"rent_price_greater"`
	RentPriceLess    int64  `form:"rent_price_less" json:"rent_price_less"`
	ApproveStatus    int64  `form:"approve_status" json:"approve_status"`
	Page             int64  `form:"page" json:"page"`
	PageSize         int64  `form:"page_size" json:"page_size"`
	BaseConf         int64  `form:"base_conf" json:"base_conf"`
	SpecialConf      int64  `form:"special_conf" json:"special_conf"`
}

type HouseRentListRequest struct {
	base.Header
	HouseRentListQuery
}

type HouseRentListResponse struct {
	base.Result
	Data pb_v1.GardenHouseRentListReply `json:"data"`
}

type HouseRentAddManagerBody struct {
	ManagerUid int64 `form:"manager_uid" json:"manager_uid"`
	RentId     int64 `form:"rent_id" json:"rent_id"`
}

type HouseRentAddManagerRequest struct {
	base.Header
	HouseRentAddManagerBody
}

type HouseRentAddManagerResponse struct {
	base.Result
	Data pb_v1.HouseRentAddManagerReply `json:"data"`
}

type HouseRentDelManagerQuery struct {
	Id int64 `form:"id" json:"id"`
}

type HouseRentDelManagerRequest struct {
	base.Header
	HouseRentDelManagerQuery
}

type HouseRentDelManagerResponse struct {
	base.Result
}
type HouseRentManagerListQuery struct {
	RentId int64 `form:"rent_id" json:"rent_id"`
}
type HouseRentManagerListRequest struct {
	base.Header
	HouseRentManagerListQuery
}

type HouseRentManagerListResponse struct {
	base.Result
	Data pb_v1.HouseRentManagerListReply `json:"data"`
}

type HouseRentAppointmentDelQuery struct {
	Id int64 `form:"id"`
}

type HouseRentAppointmentDelRequest struct {
	base.Header
	HouseRentAppointmentDelQuery
}

type HouseRentAppointmentDelResponse struct {
	base.Result
}

type HouseRentAppointmentListQuery struct {
	Page      int64  `form:"page" json:"page"`
	PageSize  int64  `form:"page_size" json:"page_size"`
	RentId    int64  `form:"rent_id" json:"rent_id"`
	HouseName string `form:"house_name" json:"house_name"`
	Name      string `form:"name" json:"name"`
	Phone     string `form:"phone" json:"phone"`
}

type HouseRentAppointmentListRequest struct {
	base.Header
	HouseRentAppointmentListQuery
}

type HouseRentAppointmentListResponse struct {
	base.Result
	Data pb_v1.HouseRentAppointmentListReply `json:"data"`
}

type HouseRentAppointmentStatusBody struct {
	Id int64 `form:"id"`
	//2 已受理，3 已拒绝，4 未到访，5已到访
	Status   int32  `form:"status"`
	Feedback string `form:"feedback"`
}

type HouseRentAppointmentStatusRequest struct {
	base.Header
	HouseRentAppointmentStatusBody
}

type HouseRentAppointmentStatusResponse struct {
	base.Result
}
