package v1

import (
	"property-system-gateway/param/base"
	"property-system-gateway/pb/v1"
)

type RepairClassAddBody struct {
	Name                 string   `form:"name" json:"name"`
	Enable               bool     `form:"enable" json:"enable"`
	// 1 公共区域 2 室内
	Area int32 `form:"area"`
}

type RepairClassAddRequest struct {
	base.Header
	RepairClassAddBody
}

type RepairClassAddResponse struct{
	base.Result
	Data v1.RepairClassAddReply `json:"data"`
}

type RepairClassUpdateBody struct {
	Name                 string   `form:"name" json:"name"`
	Enable               bool     `form:"enable" json:"enable"`
	Id int64 `form:"id"`
	Area int32 `form:"area"`
}

type RepairClassUpdateRequest struct{
	base.Header
	RepairClassUpdateBody
}

type RepairClassUpdateResponse struct{
	base.Result
}

type RepairClassDelQuery struct {
	Id int64 `form:"id"`
}

type RepairClassDelRequest struct{
	base.Header
	RepairClassDelQuery
}

type RepairClassDelResponse struct{
	base.Result
}

type RepairClassListQuery struct {
	Page                 int64    `form:"page" json:"page"`
	PageSize             int64    `form:"page_size" json:"page_size"`
	Area int32 `form:"area"`
}

type RepairClassListRequest struct{
	base.Header
	RepairClassListQuery
}

type RepairClassListResponse struct{
	base.Result
	Data v1.RepairClassListReply `json:"data"`
}



type RepairOrderAddBody struct {
	// 分类id
	ClassId int64 `form:"class_id" json:"class_id"`
	// 报修人
	ApplyPeople string `form:"apply_people" json:"apply_people"`
	// 报修人电话
	ApplyPeoplePhone string `form:"apply_people_phone" json:"apply_people_phone"`
	// 预约时间
	Appointment int64 `form:"appointment" json:"appointment"`
	// 房屋id
	HouseId int64 `form:"house_id" json:"house_id"`

	// 报修内容
	ApplyContent string `form:"apply_content" json:"apply_content"`
	// 报修图片
	ApplyPic             []string `form:"apply_pic" json:"apply_pic"`
}

type RepairOrderAddRequest struct {
	base.Header
	RepairOrderAddBody
}

type RepairOrderAddResponse struct{
	base.Result
	Data v1.RepairOrderAddReply `json:"data"`
}

type RepairOrderUpdateBody struct {
	// 分类id
	ClassId int64 `form:"class_id" json:"class_id"`
	// 报修人
	ApplyPeople string `form:"apply_people" json:"apply_people"`
	// 报修人电话
	ApplyPeoplePhone string `form:"apply_people_phone" json:"apply_people_phone"`
	// 预约时间
	Appointment int64 `form:"appointment" json:"appointment"`
	// 房屋id
	HouseId int64 `form:"house_id" json:"house_id"`

	// 报修内容
	ApplyContent string `form:"apply_content" json:"apply_content"`
	// 报修图片
	ApplyPic             []string `form:"apply_pic" json:"apply_pic"`
	Id int64 `form:"id"`

}


type RepairOrderUpdateRequest struct{
	base.Header
	RepairOrderUpdateBody
}

type RepairOrderUpdateResponse struct{
	base.Result
}

type RepairOrderDelQuery struct {
	Id int64 `form:"id"`
}

type RepairOrderDelRequest struct{
	base.Header
	RepairOrderDelQuery
}

type RepairOrderDelResponse struct{
	base.Result
}

type RepairOrderListQuery struct {
	Page                 int64    `form:"page" json:"page"`
	PageSize             int64    `form:"page_size" json:"page_size"`
	Status               int32    `form:"status" json:"status"`
	ApplyPeople          string   `form:"apply_people" json:"apply_people"`
	ApplyPeoplePhone     string   `form:"apply_people_phone" json:"apply_people_phone"`
	IsMe           bool    `form:"is_me" json:"is_me"`
	ClassId              int64    `form:"class_id" json:"class_id"`
}

type RepairOrderListRequest struct{
	base.Header
	RepairOrderListQuery
}

type RepairOrderListResponse struct{
	base.Result
	Data v1.RepairOrderListReply `json:"data"`
}

type RepairOrderInfoQuery struct {
	Id int64 `form:"id"`
}

type RepairOrderInfoRequest struct{
	base.Header
	RepairOrderInfoQuery
}

type RepairOrderInfoResponse struct{
	base.Result
	Data v1.RepairOrderInfoReply `json:"data"`
}

type RepairOrderSendBody struct {
	// 工单id
	Id                   int64    `form:"id" json:"id"`
	// 指派给谁
	CurrentUid           int64    `form:"current_uid" json:"current_uid"`
	// 意见
	Feedback             string   `form:"feedback" json:"feedback"`
}
type RepairOrderSendRequest struct{
	base.Header
	RepairOrderSendBody
}

type RepairOrderSendResponse struct{
	base.Result
}

type RepairOrderFinishBody struct {
	// 工单id
	Id                   int64    `form:"id" json:"id"`
	// 意见
	Feedback             string   `form:"feedback" json:"feedback"`
	// 处理图片
	RepairPic            []string `form:"repair_pic" json:"repair_pic"`
}
type RepairOrderFinishRequest struct{
	base.Header
	RepairOrderFinishBody
}

type RepairOrderFinishResponse struct{
	base.Result
}

type RepairOrderBackBody struct {
	// 工单id
	Id                   int64    `form:"id" json:"id"`
	// 意见
	Feedback             string   `form:"feedback" json:"feedback"`
}
type RepairOrderBackRequest struct{
	base.Header
	RepairOrderBackBody
}

type RepairOrderBackResponse struct{
	base.Result
}

type RepairOrderReturnVisitBody struct {
	Id                   int64    `form:"id" json:"id"`
	// 1 满意 2 不满意
	ReturnVisitLevel int32 `form:"return_visit_level" json:"return_visit_level"`
	// 回访内容
	ReturnVisitContent   string   `form:"return_visit_content" json:"return_visit_content"`
}

type RepairOrderReturnVisitRequest struct{
	base.Header
	RepairOrderReturnVisitBody
}

type RepairOrderReturnVisitResponse struct{
	base.Result
}


