package v1

import (
	"property-system-gateway/param/base"
	"property-system-gateway/pb/v1"
)

type VoteTopicChoiceItem struct {
	// 选项标识 如A,B,C,D
	Flag string `form:"flag" json:"flag"`
	// 选项内容
	Text string `form:"text" json:"text"`
}
type VoteTopic struct {
	// 题目类型 1 填空题 2 单选题 3 多选题 4 评分题
	TopicType int32  `form:"topic_type" json:"topic_type"`
	TopicName string `form:"topic_name" json:"topic_name"`
	// 总星数，当为评分题时有效
	Star int32 `form:"star" json:"star"`
	// 是否必选
	Must bool `form:"must" json:"must"`
	// 题目编号
	Number int64 `form:"name" json:"number"`
	// 选择题的选项
	ChoiceItems []VoteTopicChoiceItem `form:"choice_items" json:"choice_items"`
}

type VoteAddBody struct {
	// 投票标题
	Title string `form:"title" json:"title"`
	// 图片
	Pics []string `form:"pics" json:"pics"`
	// 投票开始时间
	Start int64 `form:"start" json:"start"`
	// 投票结束时间
	End int64 `form:"end" json:"end"`
	// 投票题目列表
	Topics []VoteTopic `form:"topics" json:"topics"`
}
type VoteAddRequest struct {
	base.Header
	VoteAddBody
}
type VoteAddResponse struct {
	base.Result
}

type VoteUpdateBody struct {
	// 投票id
	Id int64 `form:"id" json:"id"`
	// 投票标题
	Title string `form:"title" json:"title"`
	// 图片
	Pics []string `form:"pics" json:"pics"`
	// 投票开始时间
	Start int64 `form:"start" json:"start"`
	// 投票结束时间
	End int64 `form:"end" json:"end"`
	// 投票题目列表
	Topics []VoteTopic `form:"topics" json:"topics"`
}

type VoteUpdateRequest struct {
	base.Header
	VoteUpdateBody
}

type VoteUpdateResponse struct {
	base.Result
}

type VoteDelQuery struct {
	// 投票id
	Id int64 `form:"id" json:"id"`
}
type VoteDelRequest struct {
	base.Header
	VoteDelQuery
}

type VoteDelResponse struct {
	base.Result
}

type VoteListQuery struct {
	Page     int64  `form:"page" json:"page"`
	PageSize int64  `form:"page_size" json:"page_size"`
	Title    string `form:"title" json:"title"`
}

type VoteListRequest struct {
	base.Header
	VoteListQuery
}

type VoteListResponse struct {
	base.Result
	Data v1.VoteListReply `json:"data"`
}

type VoteResultListQuery struct {
	Page     int64 `form:"page" json:"page"`
	PageSize int64 `form:"page_size" json:"page_size"`
	// 投票id
	Id     int64 `form:"id" json:"id"`
	Number int64 `form:"number" json:"number"`
}

type VoteResultListRequest struct {
	base.Header
	VoteResultListQuery
}

type VoteResultListResponse struct {
	base.Result
	Data v1.VoteResultListReply `json:"data"`
}

type VoteResultStatisticQuery struct {
	// 投票id
	Id int64 `form:"id" json:"id"`
}

type VoteResultStatisticRequest struct {
	base.Header
	VoteResultStatisticQuery
}

type VoteResultStatisticResponse struct {
	base.Result
	Data v1.VoteResultStatisticReply `json:"data"`
}
